==> streamstore-0.1.3.tar.gz: streamstore-0.1.3/README.md <==
<div align="center">
  <p>
    <!-- Light mode logo -->
    <a href="https://s2.dev#gh-light-mode-only">
      <img src="./assets/s2-black.png" height="60">
    </a>
    <!-- Dark mode logo -->
    <a href="https://s2.dev#gh-dark-mode-only">
      <img src="./assets/s2-white.png" height="60">
    </a>
  </p>

  <p>
    <!-- PyPI -->
    <a href="https://pypi.org/project/streamstore/"><img src="https://img.shields.io/pypi/v/streamstore" /></a>
    <!-- Read the docs -->
    <a href="https://streamstore.readthedocs.io/"><img src="https://img.shields.io/readthedocs/streamstore/latest" /></a>
    <!-- Discord -->
    <a href="https://discord.gg/vTCs7kMkAf"><img src="https://img.shields.io/discord/1209937852528599092?logo=discord" /></a>
    <!-- LICENSE -->
    <a href="./LICENSE"><img src="https://img.shields.io/github/license/s2-streamstore/s2-sdk-python" /></a>
  </p>
</div>

<!-- start docs index -->

# streamstore

`streamstore` is the Python package that provides an async client for interacting with the [gRPC API](https://s2.dev/docs/interface/grpc) of [S2, the Stream Store](https://s2.dev/).

## Requirements

Python >= 3.11

## Installation

You can install the package from the [Python Package Index](https://pypi.org/project/streamstore) using the package manager of your choice. E.g., with `pip`:

```bash
pip install streamstore
```

## Documentation

API Reference is available at [streamstore.readthedocs.io](https://streamstore.readthedocs.io/).

## Examples

`examples/` directory in the repo contain examples for streaming APIs.

## Get in touch

Join our [Discord](https://discord.gg/vTCs7kMkAf) server. We would love to hear
from you.

You can also email us at [hi@s2.dev](mailto:hi@s2.dev).

==> streamstore-0.2.0.tar.gz: streamstore-0.2.0/README.md <==
<div align="center">
  <p>
    <!-- Light mode logo -->
    <a href="https://s2.dev#gh-light-mode-only">
      <img src="./assets/s2-black.png" height="60">
    </a>
    <!-- Dark mode logo -->
    <a href="https://s2.dev#gh-dark-mode-only">
      <img src="./assets/s2-white.png" height="60">
    </a>
  </p>

  <p>
    <!-- PyPI -->
    <a href="https://pypi.org/project/streamstore/"><img src="https://img.shields.io/pypi/v/streamstore" /></a>
    <!-- Read the docs -->
    <a href="https://streamstore.readthedocs.io/"><img src="https://img.shields.io/readthedocs/streamstore/latest" /></a>
    <!-- Discord -->
    <a href="https://discord.gg/vTCs7kMkAf"><img src="https://img.shields.io/discord/1209937852528599092?logo=discord" /></a>
    <!-- LICENSE -->
    <a href="./LICENSE"><img src="https://img.shields.io/github/license/s2-streamstore/s2-sdk-python" /></a>
  </p>
</div>

<!-- start docs index -->

# streamstore

`streamstore` is the Python package that provides an async client for interacting with the [gRPC API](https://s2.dev/docs/interface/grpc) of [S2, the Stream Store](https://s2.dev/).

## Project Links

- [PyPI](https://pypi.org/project/streamstore/)
- [Documentation](https://streamstore.readthedocs.io/)
- [GitHub](https://github.com/s2-streamstore/s2-sdk-python)

## Requirements

Python >= 3.11

## Installation

You can install the package from the [Python Package Index](https://pypi.org/project/streamstore) using the package manager of your choice. E.g., with `pip`:

```bash
pip install streamstore
```

## Examples

`examples/streaming` directory in the [repo](https://github.com/s2-streamstore/s2-sdk-python/tree/main/examples/streaming) contain examples for streaming APIs.

## Get in touch

Join our [Discord](https://discord.gg/vTCs7kMkAf) server. We would love to hear
from you.

You can also email us at [hi@s2.dev](mailto:hi@s2.dev).
